==> eiffelstudio-18.11.10.2592.tar: F_code/C8/ge364.c <==
/*
 * Code for class GEANT_VARIABLES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ge364.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GEANT_VARIABLES}.make */
void F1166_7969 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTGC;
	F1154_7889(Current, ((EIF_INTEGER_32) 10L));
	tr1 = RTLNS(eif_new_type(950, 0x00).id, 950, _OBJSIZ_0_0_0_0_0_0_0_0_);
	loc1 = (EIF_REFERENCE) tr1;
	F1154_7906(Current, loc1);
	RTLE;
}

/* {GEANT_VARIABLES}.has_same_keys */
EIF_BOOLEAN F1166_7970 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_11_0_0_8_);
	ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_11_0_0_8_);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
	if (Result) {
		loc1 = F1162_7965(Current);
		F1005_6900(RTCW(loc1));
		for (;;) {
			tb1 = '\01';
			tb2 = F1023_6928(RTCW(loc1));
			if (!tb2) {
				tb1 = (EIF_BOOLEAN) !Result;
			}
			if (tb1) break;
			tr1 = F1037_6949(RTCW(loc1));
			Result = F1154_7901(RTCW(arg1), tr1);
			F1005_6901(RTCW(loc1));
		}
	}
	RTLE;
	return Result;
}

/* {GEANT_VARIABLES}.set_variable_value */
void F1166_7971 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	
	
	F1154_7913(Current, arg2, arg1);
}

void EIF_Minit364 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C8/ge364.c <==
/*
 * Code for class GEANT_VARIABLES
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ge364.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {GEANT_VARIABLES}.make */
void F1170_7998 (EIF_REFERENCE Current)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLIU(2);
	
	RTGC;
	F1158_7917(Current, ((EIF_INTEGER_32) 10L));
	loc1 = RTLNS(eif_new_type(952, 0x01).id, 952, _OBJSIZ_0_0_0_0_0_0_0_0_);
	F1158_7935(Current, loc1);
	RTLE;
}

/* {GEANT_VARIABLES}.has_same_keys */
EIF_BOOLEAN F1170_7999 (EIF_REFERENCE Current, EIF_REFERENCE arg1)
{
	GTCX
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	EIF_REFERENCE tr1 = NULL;
	EIF_INTEGER_32 ti4_1;
	EIF_INTEGER_32 ti4_2;
	EIF_BOOLEAN tb1;
	EIF_BOOLEAN tb2;
	EIF_BOOLEAN Result = ((EIF_BOOLEAN) 0);
	
	RTLD;
	
	RTLI(4);
	RTLR(0,Current);
	RTLR(1,arg1);
	RTLR(2,loc1);
	RTLR(3,tr1);
	RTLIU(4);
	
	RTGC;
	ti4_1 = *(EIF_INTEGER_32 *)(Current+ _LNGOFF_11_0_0_8_);
	ti4_2 = *(EIF_INTEGER_32 *)(RTCW(arg1)+ _LNGOFF_11_0_0_8_);
	Result = (EIF_BOOLEAN) (EIF_BOOLEAN)(ti4_1 == ti4_2);
	if (Result) {
		loc1 = F1166_7994(Current);
		F1013_6929(RTCW(loc1));
		for (;;) {
			tb1 = '\01';
			tb2 = F1031_6957(RTCW(loc1));
			if (!tb2) {
				tb1 = (EIF_BOOLEAN) !Result;
			}
			if (tb1) break;
			tr1 = F1041_6976(RTCW(loc1));
			Result = F1158_7930(RTCW(arg1), tr1);
			F1013_6930(RTCW(loc1));
		}
	}
	RTLE;
	return Result;
}

/* {GEANT_VARIABLES}.set_variable_value */
void F1170_8000 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2)
{
	GTCX
	
	
	F1158_7942(Current, arg2, arg1);
}

void EIF_Minit364 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
